#!/bin/sh
#
# Component: dotcom
#
# Description:
#   Applies proliferated SQL query.
#
# Usage:
#   applyquery.sh [-n] -f <filename> -d <direction> -x <excepthost>
#
#      -f <filename>   : name of the query file (proliferate)
#      -n              : do not proliferate to Database servers
#      -x <excepthost> : don't send the file to this host
#      -d <direction>  : direction of proliferation {up|down|all}, default is all
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

LOGGER="/usr/bin/logger"
TAG="applyquery[$$]"

#
# Usage
#
usage_()
{
	if [ -n "$1" ] ; then
		echo $1
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "$1"
	fi
	cat <<- ENDOFUSAGE
		applyquery.sh [-n] -f <filename> -d <direction> -x <excepthost>
	
		 -f <filename>   : name of the query file (proliferate)
		 -n              : do not proliferate to Database servers
		 -x <excepthost> : don't send the file to this host
		 -d <direction>  : direction of proliferation {up|down|all}, default is all
		 -r              : remote execution only
	ENDOFUSAGE

	[ -n "$1" ] && exit 1
	exit 0
} # usage


ERRMSG=""
FILENAME=""
PDIRECTION=""
PEXCEPT=""
SKIPLOCAL=""
EXCLUDE_DBONLY=""

while getopts 'f:x:d:nr' OPT; do
	case $OPT in
		f) FILENAME="$OPTARG" ;;
		x) PEXCEPT="-x \"$OPTARG\"" ;;
		d) PDIRECTION="-d \"$OPTARG\"" ;;
		n) EXCLUDE_DBONLY="-n" ;;
		r) SKIPLOCAL="true" ;;
		*) usage_ "Invalid_Parameter:$OPT" ;;
	esac
done

[ -z "$FILENAME" ] && usage_ "Missing Parameter"

[ ! -f "$FILENAME" ] && exit 1

if [ -z "$SKIPLOCAL" ] ; then
	$MYSQL_HOME/bin/mysql --force $DBNAME < "$FILENAME" >/dev/null 2>&1

	if [ $? -ne 0 ] ; then
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "MySQL error [$FILENAME]"
		exit 1
	fi
fi

$TASKD_HOME/createtaskfileapp -p "PROLIFERATE" -t "sh" -c "$DOTCOM_HOME/proliferate.sh -f \"$FILENAME\" $EXCLUDE_DBONLY $PDIRECTION $PEXCEPT -r \"$DOTCOM_HOME/applyquery.sh\""
exit 0
