#!/bin/sh
#
# Component: dotcom
#
# Description:
#   Proliferates a directory in the dotcom.
#
# Usage:
#    proliferatedir.sh -f <directoryname> [-n] [-d <direction>] [-x <excepthost>]
#         [[-r <script>] [-a <scriptarg>]]
#
#      -f <directoryname> : directory to proliferate
#      -n                 : do not proliferate to Database servers
#      -x <excepthost>    : don't send the file to this host
#      -d <direction>     : direction of proliferate {up|down|all}, default is all
#      -r <script>        : run this script on the target
#      -a <scriptarg>     : params passed to script
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

LOGGER="/usr/bin/logger"
TAG="proliferatedir[$$]"

#
# Usage
#
usage_()
{
	if [ -n "$1" ] ; then
		echo $1
		$LOGGER -p $LOG_FACILITY.err -t "$TAG" "$1"
	fi
	cat <<- ENDOFUSAGE
		proliferatedir.sh -f <directoryname> [-n] [-d <direction>] [-x <excepthost>]
		     [[-r <script>] [-a <scriptarg>]]
	
		 -f <directoryname> : directory to proliferate
		 -n                 : do not proliferate to Database servers
		 -x <excepthost>    : don't send the file to this host
		 -d <direction>     : direction of proliferate {up|down|all}, default is all
		 -r <script>        : run this script on the target
		 -a <scriptarg>     : params passed to script
	ENDOFUSAGE

	[ -n "$1" ] && exit 1
	exit 0
} # usage


ERRMSG=""
DIRNAME=""
DIRECTION="all"
EXCEPT=""

PEXCEPT=""
PDIRECTION=""
PSCRIPTNAME="-r $DOTCOM_HOME/applystoredir.sh"
PSCRIPTARGS=""

EXCLUDE_DBONLY=""

while getopts 'f:x:d:r:a:n' OPT; do
	case $OPT in
		f) DIRNAME="$OPTARG" ;;
		x) EXCEPT="$OPTARG" ;;
		d) DIRECTION="$OPTARG" ;;
		r) PSCRIPTNAME="-r \"$OPTARG\"" ;;
		a) PSCRIPTARGS="$PSCRIPTARGS -a \"$OPTARG\"" ;;
		n) EXCLUDE_DBONLY="-n" ;;
		*) usage_ "Invalid_Parameter:$OPT" ;;
	esac
done

[ -z "$DIRNAME" ] && usage_ "Missing Parameter"

if [ ! -d "$DIRNAME" ] ; then
#don't retry
	echo "Directory $DIRNAME doesn't exist"
	$LOGGER -p $LOG_FACILITY.err -t "$TAG" "Directory $DIRNAME doesn't exist"
	exit 1
fi

[ -n "$EXCEPT" ] && PEXCEPT="-x $EXCEPT"
[ -n "$DIRECTION" ] && PDIRECTION="-d $DIRECTION"

D_NAME=`dirname "$DIRNAME"`
B_NAME=`basename "$DIRNAME"`

DATE=`date +%Y%m%d%H%M%S`
PID=$$
DIR_TAR_NAME=$TMP/directory.$DATE.$PID.tar
PSCRIPTARGS="$PSCRIPTARGS -a -t -a \"$D_NAME\""

CWD=`pwd`
cd "$D_NAME"

tar -cf $DIR_TAR_NAME "$B_NAME"

cd "$CWD"

[ $? -ne 0 ] && exit 1

$TASKD_HOME/createtaskfileapp -p "PROLIFERATE" -t "sh" -c "$DOTCOM_HOME/proliferate.sh -f \"$DIR_TAR_NAME\" $EXCLUDE_DBONLY $PDIRECTION $PEXCEPT $PSCRIPTNAME $PSCRIPTARGS"

exit 0
